@@ -16,14 +16,14 @@
 #  drives is a pain in the butt
 # 2-May-2002 - SGhosh fix for embedded perl
 #
-# $Id: check_disk_smb.pl,v 1.8.2.1 2003/07/02 15:52:23 tonvoon Exp $
+# $Id: check_disk_smb.pl,v 1.12 2005/04/17 22:22:41 seanius Exp $
 #
 
 require 5.004;
 use POSIX;
 use strict;
 use Getopt::Long;
-use vars qw($opt_V $opt_h $opt_H $opt_s $opt_W $opt_u $opt_p $opt_w $opt_c $verbose);
+use vars qw($opt_P $opt_V $opt_h $opt_H $opt_s $opt_W $opt_u $opt_p $opt_w $opt_c $verbose);
 use vars qw($PROGNAME);
 use lib utils.pm ;
 use utils qw($TIMEOUT %ERRORS &print_revision &support &usage);
@@ -40,6 +40,7 @@ $ENV{'ENV'}='';
 Getopt::Long::Configure('bundling');
 GetOptions
 	("v"   => \$verbose, "verbose"    => \$verbose,
+	 "P=s" => \$opt_P, "port=s"     => \$opt_P,
 	 "V"   => \$opt_V, "version"    => \$opt_V,
 	 "h"   => \$opt_h, "help"       => \$opt_h,
 	 "w=s" => \$opt_w, "warning=s"  => \$opt_w,
@@ -51,14 +52,14 @@ GetOptions
 	 "H=s" => \$opt_H, "hostname=s" => \$opt_H);
 
 if ($opt_V) {
-	print_revision($PROGNAME,'$Revision: 1.8.2.1 $'); #'
+	print_revision($PROGNAME,'$Revision: 1.12 $'); #'
 	exit $ERRORS{'OK'};
 }
 
 if ($opt_h) {print_help(); exit $ERRORS{'OK'};}
 
 my $smbclient= "$utils::PATH_TO_SMBCLIENT " ;
-my $smbclientoptions="";
+my $smbclientoptions= $opt_P ? "-p $opt_P " : "";
 
 
 # Options checking
@@ -75,7 +76,7 @@ my $share = $1 if ($opt_s =~ /^([-_.A-Za-z0-9]+\$?)$/);
 my $user = $1 if ($opt_u =~ /^([-_.A-Za-z0-9\\]+)$/);
 ($user) || usage("Invalid user: $opt_u\n");
 
-($opt_p) || ($opt_p = shift) || ($opt_p = "guest");
+($opt_p) || ($opt_p = shift) || ($opt_p = "");
 my $pass = $1 if ($opt_p =~ /(.*)/);
 
 ($opt_w) || ($opt_w = shift) || ($opt_w = 85);
@@ -122,10 +123,10 @@ alarm($TIMEOUT);
 # Execute an "ls" on the share using smbclient program
 # get the results into $res
 if (defined($workgroup)) {
-	$res = qx/$smbclient \/\/$host\/$share $pass -W $workgroup -U $user $smbclientoptions -c ls/;
+	$res = qx/$smbclient \/\/$host\/$share -W $workgroup -U $user%$pass $smbclientoptions -c ls/;
 } else {
 	print "$smbclient " . "\/\/$host\/$share" ." $pass -U $user $smbclientoptions -c ls\n" if ($verbose);
-	$res = qx/$smbclient \/\/$host\/$share $pass -U $user $smbclientoptions -c ls/;
+	$res = qx/$smbclient \/\/$host\/$share -U $user%$pass $smbclientoptions -c ls/;
 }
 #Turn off alarm
 alarm(0);
@@ -230,11 +231,11 @@ exit $ERRORS{$state};
 
 sub print_usage () {
 	print "Usage: $PROGNAME -H <host> -s <share> -u <user> -p <password> 
-      -w <warn> -c <crit> [-W <workgroup>]\n";
+      -w <warn> -c <crit> [-W <workgroup>] [-P <port>]\n";
 }
 
 sub print_help () {
-	print_revision($PROGNAME,'$Revision: 1.8.2.1 $');
+	print_revision($PROGNAME,'$Revision: 1.12 $');
 	print "Copyright (c) 2000 Michael Anthon/Karl DeBisschop
 
 Perl Check SMB Disk plugin for Nagios
@@ -251,12 +252,14 @@ Perl Check SMB Disk plugin for Nagios
 -u, --user=STRING
    Username to log in to server. (Defaults to \"guest\")
 -p, --password=STRING
-   Password to log in to server. (Defaults to \"guest\")
+   Password to log in to server. (Defaults to an empty password)
 -w, --warning=INTEGER or INTEGER[kMG]
    Percent of used space at which a warning will be generated (Default: 85%)
       
 -c, --critical=INTEGER or INTEGER[kMG]
    Percent of used space at which a critical will be generated (Defaults: 95%)
+-P, --port=INTEGER
+   Port to be used to connect to. Some Windows boxes use 139, others 445 (Defaults to smbclient default)
    
    If thresholds are followed by either a k, M, or G then check to see if that
    much disk space is available (kilobytes, Megabytes, Gigabytes)
