@@ -14,13 +14,13 @@
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
- $Id: check_disk.c,v 1.56 2004/12/25 23:17:44 opensides Exp $
+ $Id: check_disk.c,v 1.57 2005/03/04 21:58:40 tonvoon Exp $
  
 *****************************************************************************/
 
 const char *progname = "check_disk";
-const char *program_name = "check_disk";	// Required for coreutils libs
-const char *revision = "$Revision: 1.56 $";
+const char *program_name = "check_disk";	/* Required for coreutils libs */
+const char *revision = "$Revision: 1.57 $";
 const char *copyright = "1999-2004";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
