@@ -7,7 +7,7 @@
 * Copyright (c) 1999 Didi Rieder (adrieder@sbox.tu-graz.ac.at)
 *  portions (c) 2000 Karl DeBisschop (kdebisschop@users.sourceforge.net)
 * 
-* $Id: check_mysql.c,v 1.24 2004/12/25 23:17:44 opensides Exp $
+* $Id: check_mysql.c,v 1.26 2005/05/26 02:13:19 seanius Exp $
 *
 * Description:
 *
@@ -15,7 +15,7 @@
 ******************************************************************************/
 
 const char *progname = "check_mysql";
-const char *revision = "$Revision: 1.24 $";
+const char *revision = "$Revision: 1.26 $";
 const char *copyright = "1999-2004";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
@@ -125,8 +125,33 @@ main (int argc, char **argv)
 
 		} else {
 			/* mysql 4.x.x */
-			snprintf (slaveresult, SLAVERESULTSIZE, "Slave IO: %s Slave SQL: %s", row[9], row[10]);
-			if (strcmp (row[9], "Yes") != 0 || strcmp (row[10], "Yes") != 0) {
+			int slave_io_field = -1 , slave_sql_field = -1, i, num_fields;
+			MYSQL_FIELD* fields;
+
+			num_fields = mysql_num_fields(res);
+			fields = mysql_fetch_fields(res);
+			for(i = 0; i < num_fields; i++)
+			{
+				if (0 == strcmp(fields[i].name, "Slave_IO_Running"))
+				{
+					slave_io_field = i;
+					continue;
+				}
+				if (0 == strcmp(fields[i].name, "Slave_SQL_Running"))
+				{
+					slave_sql_field = i;
+					continue;
+				}
+			}
+			if ((slave_io_field < 0) || (slave_sql_field < 0) || (num_fields == 0))
+			{
+				mysql_free_result (res);
+				mysql_close (&mysql);
+				die (STATE_CRITICAL, "Slave status unavailable\n");
+			}
+			 
+			snprintf (slaveresult, SLAVERESULTSIZE, "Slave IO: %s Slave SQL: %s", row[slave_io_field], row[slave_sql_field]);
+			if (strcmp (row[slave_io_field], "Yes") != 0 || strcmp (row[slave_sql_field], "Yes") != 0) {
 				mysql_free_result (res);
 				mysql_close (&mysql);
 				die (STATE_CRITICAL, "%s\n", slaveresult);
