@@ -14,12 +14,12 @@
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
- $Id: check_smtp.c,v 1.43 2005/01/01 16:15:39 tonvoon Exp $
+ $Id: check_smtp.c,v 1.46 2005/04/07 04:33:33 seanius Exp $
  
 ******************************************************************************/
 
 const char *progname = "check_smtp";
-const char *revision = "$Revision: 1.43 $";
+const char *revision = "$Revision: 1.46 $";
 const char *copyright = "2000-2004";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
@@ -76,7 +76,7 @@ int my_close(void);
 char regex_expect[MAX_INPUT_BUFFER] = "";
 regex_t preg;
 regmatch_t pmatch[10];
-char timestamp[10] = "";
+char timestamp[20] = "";
 char errbuf[MAX_INPUT_BUFFER];
 int cflags = REG_EXTENDED | REG_NOSUB | REG_NEWLINE;
 int eflags = 0;
@@ -177,12 +177,19 @@ main (int argc, char **argv)
 				result = STATE_WARNING;
 			}
 		}
+
+		/* send the HELO command */
+		send(sd, helocmd, strlen(helocmd), 0);
+
+		/* allow for response to helo command to reach us */
+		read (sd, buffer, MAXBUF - 1);
+
 #ifdef HAVE_SSL
 		if(use_ssl) {
 		  /* send the STARTTLS command */
 		  send(sd, SMTP_STARTTLS, strlen(SMTP_STARTTLS), 0);
 
-		  recv(sd,buffer, MAX_INPUT_BUFFER-1, 0); // wait for it
+		  recv(sd,buffer, MAX_INPUT_BUFFER-1, 0); /* wait for it */
 		  if (!strstr (buffer, server_expect)) {
 		    printf (_("Server does not support STARTTLS\n"));
 		    return STATE_UNKNOWN;
@@ -206,16 +213,6 @@ main (int argc, char **argv)
 		  }
 		}
 #endif
-		/* send the HELO command */
-#ifdef HAVE_SSL
-		if (use_ssl)
-		  SSL_write(ssl, helocmd, strlen(helocmd));
-		else
-#endif
-		send(sd, helocmd, strlen(helocmd), 0);
-
-		/* allow for response to helo command to reach us */
-		myrecv();
 				
 		/* sendmail will syslog a "NOQUEUE" error if session does not attempt
 		 * to do something useful. This can be prevented by giving a command
@@ -254,8 +251,6 @@ main (int argc, char **argv)
 			if (n < nresponses) {
 #ifdef HAVE_REGEX_H
 				cflags |= REG_EXTENDED | REG_NOSUB | REG_NEWLINE;
-				//strncpy (regex_expect, responses[n], sizeof (regex_expect) - 1);
-				//regex_expect[sizeof (regex_expect) - 1] = '\0';
 				errcode = regcomp (&preg, responses[n], cflags);
 				if (errcode != 0) {
 					regerror (errcode, &preg, errbuf, MAX_INPUT_BUFFER);
@@ -610,7 +605,7 @@ connect_STARTTLS (void)
   /* this causes a seg faul
      not sure why, being sloppy
      and commenting it out */
-  //  SSL_free (ssl);
+  /*  SSL_free (ssl); */
   SSL_CTX_free(ctx);
   my_close();
   
@@ -667,7 +662,7 @@ check_certificate (X509 ** certificate)
   
   days_left = (mktime (&stamp) - time (NULL)) / 86400;
   snprintf
-    (timestamp, 16, "%02d/%02d/%04d %02d:%02d",
+    (timestamp, sizeof(timestamp), "%02d/%02d/%04d %02d:%02d",
      stamp.tm_mon + 1,
      stamp.tm_mday, stamp.tm_year + 1900, stamp.tm_hour, stamp.tm_min);
   
