@@ -21,12 +21,12 @@
  *
  * Copyright (c) 2000 Karl DeBisschop (kdebisschop@users.sourceforge.net)
  *
- * $Id: check_swap.c,v 1.47 2005/01/19 21:14:47 tonvoon Exp $
+ * $Id: check_swap.c,v 1.51 2005/07/06 22:10:04 tonvoon Exp $
  *
  *****************************************************************************/
 
 const char *progname = "check_swap";
-const char *revision = "$Revision: 1.47 $";
+const char *revision = "$Revision: 1.51 $";
 const char *copyright = "2000-2004";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
@@ -42,8 +42,8 @@ void print_help (void);
 
 int warn_percent = 0;
 int crit_percent = 0;
-float warn_size = 0;
-float crit_size = 0;
+double warn_size = 0;
+double crit_size = 0;
 int verbose;
 int allswaps;
 
@@ -79,14 +79,13 @@ main (int argc, char **argv)
 # endif
 #endif
 	char str[32];
-	char *status, *tmp_status;
+	char *status;
 
 	setlocale (LC_ALL, "");
 	bindtextdomain (PACKAGE, LOCALEDIR);
 	textdomain (PACKAGE);
 
 	status = strdup ("");
-	tmp_status = strdup ("");
 	perf = strdup ("");
 
 	if (process_arguments (argc, argv) == ERROR)
@@ -311,19 +310,24 @@ main (int argc, char **argv)
 # endif /* HAVE_SWAP */
 #endif /* HAVE_PROC_MEMINFO */
 
-	percent_used = 100 * ((double) used_swap) / ((double) total_swap);
+	/* if total_swap == 0, let's not divide by 0 */
+	if(total_swap) {
+		percent_used = 100 * ((double) used_swap) / ((double) total_swap);
+	} else {
+		percent_used = 0;
+	}
+
 	result = max_state (result, check_swap (percent_used, free_swap));
-	/* broken into two steps because of funkiness with builtin asprintf */
-	asprintf (&tmp_status, _(" %d%% free (%.0f MB out of %.0f MB)"),
-						(100 - percent_used), free_swap, total_swap);
-	asprintf (&status, "%s%s", tmp_status, status);
+	printf (_("SWAP %s - %d%% free (%.0f MB out of %.0f MB) %s|"),
+			state_text (result),
+			(100 - percent_used), free_swap, total_swap, status);
+
+	puts (perfdata ("swap", (long) free_swap, "MB",
+	                TRUE, (long) max (warn_size/1024, warn_percent/100.0*total_swap),
+	                TRUE, (long) max (crit_size/1024, crit_percent/100.0*total_swap),
+	                TRUE, 0,
+	                TRUE, (long) total_swap));
 
-	asprintf (&perf, "%s", perfdata ("swap", (long) free_swap, "MB",
-		TRUE, (long) max (warn_size/1024, warn_percent/100.0*total_swap),
-		TRUE, (long) max (crit_size/1024, crit_percent/100.0*total_swap),
-		TRUE, 0,
-		TRUE, (long) total_swap));
-	printf ("SWAP %s:%s |%s\n", state_text (result), status, perf);
 	return result;
 }
 
@@ -378,12 +382,13 @@ process_arguments (int argc, char **argv)
 		switch (c) {
 		case 'w':									/* warning size threshold */
 			if (is_intnonneg (optarg)) {
-				warn_size = (float) atoi (optarg);
+				warn_size = (double) atoi (optarg);
 				break;
 			}
 			else if (strstr (optarg, ",") &&
 							 strstr (optarg, "%") &&
-							 sscanf (optarg, "%.0f,%d%%", &warn_size, &warn_percent) == 2) {
+							 sscanf (optarg, "%g,%d%%", &warn_size, &warn_percent) == 2) {
+				warn_size = floor(warn_size);
 				break;
 			}
 			else if (strstr (optarg, "%") &&
@@ -395,12 +400,13 @@ process_arguments (int argc, char **argv)
 			}
 		case 'c':									/* critical size threshold */
 			if (is_intnonneg (optarg)) {
-				crit_size = (float) atoi (optarg);
+				crit_size = (double) atoi (optarg);
 				break;
 			}
 			else if (strstr (optarg, ",") &&
 							 strstr (optarg, "%") &&
-							 sscanf (optarg, "%.0f,%d%%", &crit_size, &crit_percent) == 2) {
+							 sscanf (optarg, "%g,%d%%", &crit_size, &crit_percent) == 2) {
+				crit_size = floor(crit_size);
 				break;
 			}
 			else if (strstr (optarg, "%") &&
@@ -441,12 +447,12 @@ process_arguments (int argc, char **argv)
 	if (c == argc)
 		return validate_arguments ();
 	if (warn_size == 0 && is_intnonneg (argv[c]))
-		warn_size = (float) atoi (argv[c++]);
+		warn_size = (double) atoi (argv[c++]);
 
 	if (c == argc)
 		return validate_arguments ();
 	if (crit_size == 0 && is_intnonneg (argv[c]))
-		crit_size = atoi (argv[c++]);
+		crit_size = (double) atoi (argv[c++]);
 
 	return validate_arguments ();
 }
@@ -500,10 +506,6 @@ print_help (void)
  -v, --verbose\n\
     Verbose output. Up to 3 levels\n"));
 
-	printf (_("\n\
-On Solaris, if -a specified, uses swap -l, otherwise uses swap -s.\n\
-Will be discrepencies because swap -s counts allocated swap and includes\n\
-real memory\n"));
 	printf (_("\n\
 On AIX, if -a is specified, uses lsps -a, otherwise uses lsps -s.\n"));
 
