@@ -5,7 +5,7 @@
 * License: GPL
 * Copyright (c) 1999 Ethan Galstad (nagios@nagios.org)
 *
-* Last Modified: $Date: 2004/12/25 23:17:44 $
+* Last Modified: $Date: 2005/05/25 00:30:19 $
 *
 * Description:
 *
@@ -27,7 +27,7 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
-* $Id: netutils.c,v 1.22 2004/12/25 23:17:44 opensides Exp $
+* $Id: netutils.c,v 1.24 2005/05/25 00:30:19 seanius Exp $
 *
 ****************************************************************************/
 
@@ -39,7 +39,6 @@ int econn_refuse_state = STATE_CRITICAL;
 int was_refused = FALSE;
 int address_family = AF_UNSPEC;
 
-static int my_connect(const char *address, int port, int *sd, int proto);
 /* handles socket timeouts */
 void
 socket_timeout_alarm_handler (int sig)
@@ -53,37 +52,6 @@ socket_timeout_alarm_handler (int sig)
 }
 
 
-/* connects to a host on a specified TCP port, sends a string,
-   and gets a response */
-int
-process_tcp_request (const char *server_address, int server_port,
-	const char *send_buffer, char *recv_buffer, int recv_size)
-{
-	int result;
-
-	result = process_request (server_address, server_port,
-			IPPROTO_TCP, send_buffer, recv_buffer, recv_size);
-
-	return result;
-}
-
-
-/* connects to a host on a specified UDP port, sends a string, and gets a
-    response */
-int
-process_udp_request (const char *server_address, int server_port,
-	const char *send_buffer, char *recv_buffer, int recv_size)
-{
-	int result;
-
-	result = process_request (server_address, server_port,
-			IPPROTO_UDP, send_buffer, recv_buffer, recv_size);
-
-	return result;
-}
-
-
-
 /* connects to a host on a specified tcp port, sends a string, and gets a 
 	 response. loops on select-recv until timeout or eof to get all of a 
 	 multi-packet answer */
@@ -100,7 +68,7 @@ process_tcp_request2 (const char *server_address, int server_port,
 	fd_set readfds;
 	int recv_length = 0;
 
-	result = my_connect (server_address, server_port, &sd, IPPROTO_TCP);
+	result = np_net_connect (server_address, server_port, &sd, IPPROTO_TCP);
 	if (result != STATE_OK)
 		return STATE_CRITICAL;
 
@@ -163,6 +131,7 @@ process_tcp_request2 (const char *server_address, int server_port,
 	return result;
 }
 
+
 /* connects to a host on a specified port, sends a string, and gets a 
    response */
 int
@@ -174,7 +143,7 @@ process_request (const char *server_address, int server_port, int proto,
 
 	result = STATE_OK;
 
-	result = my_connect (server_address, server_port, &sd, proto);
+	result = np_net_connect (server_address, server_port, &sd, proto);
 	if (result != STATE_OK)
 		return STATE_CRITICAL;
 
@@ -186,33 +155,9 @@ process_request (const char *server_address, int server_port, int proto,
 }
 
 
-/* opens a connection to a remote host/tcp port */
-int
-my_tcp_connect (const char *host_name, int port, int *sd)
-{
-	int result;
-
-	result = my_connect (host_name, port, sd, IPPROTO_TCP);
-
-	return result;
-}
-
-
-/* opens a connection to a remote host/udp port */
-int
-my_udp_connect (const char *host_name, int port, int *sd)
-{
-	int result;
-
-	result = my_connect (host_name, port, sd, IPPROTO_UDP);
-
-	return result;
-}
-
-
 /* opens a tcp or udp connection to a remote host */
-static int
-my_connect (const char *host_name, int port, int *sd, int proto)
+int
+np_net_connect (const char *host_name, int port, int *sd, int proto)
 {
 	struct addrinfo hints;
 	struct addrinfo *res, *res0;
@@ -290,20 +235,6 @@ my_connect (const char *host_name, int port, int *sd, int proto)
 }
 
 
-int
-send_tcp_request (int sd, const char *send_buffer, char *recv_buffer, int recv_size)
-{
-	return send_request (sd, IPPROTO_TCP, send_buffer, recv_buffer, recv_size);
-}
-
-
-int
-send_udp_request (int sd, const char *send_buffer, char *recv_buffer, int recv_size)
-{
-	return send_request (sd, IPPROTO_UDP, send_buffer, recv_buffer, recv_size);
-}
-
-
 int
 send_request (int sd, int proto, const char *send_buffer, char *recv_buffer, int recv_size)
 {
@@ -397,28 +328,3 @@ resolve_host_or_addr (const char *address, int family)
 		return TRUE;
 	}
 }
-
-int
-is_inet_addr (const char *address)
-{
-	return resolve_host_or_addr (address, AF_INET);
-}
-
-#ifdef USE_IPV6
-int
-is_inet6_addr (const char *address)
-{
-	return resolve_host_or_addr (address, AF_INET6);
-}
-#endif
-
-int
-is_hostname (const char *s1)
-{
-#ifdef USE_IPV6
-	return resolve_host_or_addr (s1, address_family);
-#else
-	return resolve_host_or_addr (s1, AF_INET);
-#endif
-}
-
