@@ -16,7 +16,7 @@ int spclose(FILE *);
  * path passed to the exec'd program are esstially empty. (popen create a shell
  * and passes the environment to it).
  *
- * $Id: popen.c,v 1.11 2004/12/25 23:17:44 opensides Exp $
+ * $Id: popen.c,v 1.12 2005/05/01 20:12:03 seanius Exp $
  *
  ******************************************************************************/
 
@@ -243,8 +243,12 @@ static int openmax = 0;
 void
 popen_timeout_alarm_handler (int signo)
 {
+	int fh;
 	if (signo == SIGALRM) {
-		kill (childpid[fileno (child_process)], SIGKILL);
+		fh=fileno (child_process);
+		if(fh >= 0){
+			kill (childpid[fh], SIGKILL);
+		}
 		printf (_("CRITICAL - Plugin timed out after %d seconds\n"),
 						timeout_interval);
 		exit (STATE_CRITICAL);
